You are viewing a plain text version of this content. The canonical link for it is here.
Posted to jetspeed-dev@portals.apache.org by at...@apache.org on 2008/10/17 01:02:01 UTC

svn commit: r705396 [3/3] - in /portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade: components/jetspeed-portal/src/main/java/org/apache/jetspeed/ components/jetspeed-portal/src/main/java/org/apache/jetspeed/aggregator/impl/ components/jetspee...

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/components/jetspeed-search/src/main/java/org/apache/jetspeed/search/handlers/pam/PortletDefinitionHandler.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/components/jetspeed-search/src/main/java/org/apache/jetspeed/search/handlers/pam/PortletDefinitionHandler.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/components/jetspeed-search/src/main/java/org/apache/jetspeed/search/handlers/pam/PortletDefinitionHandler.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/components/jetspeed-search/src/main/java/org/apache/jetspeed/search/handlers/pam/PortletDefinitionHandler.java Thu Oct 16 16:01:57 2008
@@ -22,8 +22,8 @@
 
 import org.apache.commons.collections.MultiHashMap;
 import org.apache.jetspeed.om.common.LocalizedField;
-import org.apache.jetspeed.om.common.portlet.PortletApplication;
-import org.apache.jetspeed.om.common.portlet.PortletDefinitionComposite;
+import org.apache.jetspeed.om.portlet.PortletApplication;
+import org.apache.jetspeed.om.portlet.PortletDefinition;
 import org.apache.jetspeed.search.AbstractObjectHandler;
 import org.apache.jetspeed.search.BaseParsedObject;
 import org.apache.jetspeed.search.ParsedObject;
@@ -52,10 +52,10 @@
     public ParsedObject parseObject(Object o)
     {
         BaseParsedObject result = null;
-        if(o instanceof PortletDefinitionComposite)
+        if(o instanceof PortletDefinition)
         {
             result = new BaseParsedObject();
-            PortletDefinitionComposite pd = (PortletDefinitionComposite)o;
+            PortletDefinition pd = (PortletDefinition)o;
             
             //need to get Locale here
             String displayNameText = pd.getDisplayNameText(JetspeedLocale.getDefaultLocale());

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletpreferences/PortletPreferencesProvider.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletpreferences/PortletPreferencesProvider.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletpreferences/PortletPreferencesProvider.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletpreferences/PortletPreferencesProvider.java Thu Oct 16 16:01:57 2008
@@ -19,17 +19,17 @@
 import java.util.Iterator;
 
 import org.apache.jetspeed.container.PortletEntity;
-import org.apache.jetspeed.om.common.portlet.PortletDefinitionComposite;
 import org.apache.jetspeed.om.common.preference.PreferenceSetComposite;
+import org.apache.jetspeed.om.portlet.PortletDefinition;
 
 public interface PortletPreferencesProvider
 {
     void init() throws Exception;
-    public PreferenceSetComposite getPreferenceSet(PortletDefinitionComposite pd);
+    public PreferenceSetComposite getPreferenceSet(PortletDefinition pd);
     public PreferenceSetComposite getPreferenceSet(PortletEntity pe);
     public PreferenceSetComposite getPreferenceSet(PortletEntity pe, String userName);
     public Iterator<String> getUserNames(PortletEntity pe);
-    public void savePreferenceSet(PortletDefinitionComposite pd, PreferenceSetComposite preferenceSet);
+    public void savePreferenceSet(PortletDefinition pd, PreferenceSetComposite preferenceSet);
     public void savePreferenceSet(PortletEntity pe, PreferenceSetComposite preferenceSet);
     public void savePreferenceSet(PortletEntity pe, String userName, PreferenceSetComposite preferenceSet);        
 }

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletregistry/PortletRegistry.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletregistry/PortletRegistry.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletregistry/PortletRegistry.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletregistry/PortletRegistry.java Thu Oct 16 16:01:57 2008
@@ -18,8 +18,8 @@
 
 import java.util.Collection;
 
-import org.apache.jetspeed.om.common.portlet.PortletApplication;
-import org.apache.jetspeed.om.common.portlet.PortletDefinitionComposite;
+import org.apache.jetspeed.om.portlet.PortletApplication;
+import org.apache.jetspeed.om.portlet.PortletDefinition;
 import org.apache.pluto.om.portlet.PortletApplicationDefinition;
 import org.apache.pluto.om.portlet.PortletDefinition;
 
@@ -68,7 +68,7 @@
      * have a parent PortletApplicationDefinition
      * 
      */
-    PortletDefinitionComposite getPortletDefinitionByUniqueName( String name );
+    PortletDefinition getPortletDefinitionByUniqueName( String name );
 
     /**
      * Checks whether or not a portlet application with this name has all ready

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletregistry/RegistryEventListener.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletregistry/RegistryEventListener.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/factory/PortletFactory.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/factory/PortletFactory.java Thu Oct 16 16:01:57 2008
@@ -20,7 +20,7 @@
 import javax.portlet.PreferencesValidator;
 import javax.servlet.ServletContext;
 
-import org.apache.jetspeed.om.common.portlet.PortletApplication;
+import org.apache.jetspeed.om.portlet.PortletApplication;
 import org.apache.pluto.om.portlet.PortletDefinition;
 
 /**

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/portlet/MockPortletRequest.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/portlet/MockPortletRequest.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/portlet/MockPortletRequest.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/portlet/MockPortletRequest.java Thu Oct 16 16:01:57 2008
@@ -27,6 +27,7 @@
 import javax.portlet.PortletRequest;
 import javax.portlet.PortletSession;
 import javax.portlet.WindowState;
+import javax.servlet.http.Cookie;
 
 /**
  * A mock portlet request, useful for unit testing and offline utilities
@@ -42,47 +43,6 @@
     {
         session = new MockPortletSession();     
     }
-    
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#isWindowStateAllowed(javax.portlet.WindowState)
-     */
-    public boolean isWindowStateAllowed(WindowState state)
-    {
-        // TODO Auto-generated method stub
-        return false;
-    }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#isPortletModeAllowed(javax.portlet.PortletMode)
-     */
-    public boolean isPortletModeAllowed(PortletMode mode)
-    {
-        // TODO Auto-generated method stub
-        return false;
-    }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getPortletMode()
-     */
-    public PortletMode getPortletMode()
-    {
-        // TODO Auto-generated method stub
-        return null;
-    }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getWindowState()
-     */
-    public WindowState getWindowState()
-    {
-        // TODO Auto-generated method stub
-        return null;
-    }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getPreferences()
-     */
-    public PortletPreferences getPreferences()
-    {
-        // TODO Auto-generated method stub
-        return null;
-    }
     /* (non-Javadoc)
      * @see javax.portlet.PortletRequest#getPortletSession()
      */
@@ -101,216 +61,183 @@
         }
         return session;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getProperty(java.lang.String)
-     */
-    public String getProperty(String name)
+    
+    public Object getAttribute(String arg0)
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getProperties(java.lang.String)
-     */
-    public Enumeration getProperties(String name)
+    public Enumeration<String> getAttributeNames()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getPropertyNames()
-     */
-    public Enumeration getPropertyNames()
+    public String getAuthType()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getPortalContext()
-     */
-    public PortalContext getPortalContext()
+    public String getContextPath()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getAuthType()
-     */
-    public String getAuthType()
+    public Cookie[] getCookies()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getContextPath()
-     */
-    public String getContextPath()
+    public Locale getLocale()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getRemoteUser()
-     */
-    public String getRemoteUser()
+    public Enumeration<Locale> getLocales()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getUserPrincipal()
-     */
-    public Principal getUserPrincipal()
+    public String getParameter(String arg0)
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#isUserInRole(java.lang.String)
-     */
-    public boolean isUserInRole(String role)
+    public Map<String, String[]> getParameterMap()
     {
         // TODO Auto-generated method stub
-        return false;
+        return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getAttribute(java.lang.String)
-     */
-    public Object getAttribute(String name)
+    public Enumeration<String> getParameterNames()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getAttributeNames()
-     */
-    public Enumeration getAttributeNames()
+    public String[] getParameterValues(String arg0)
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getParameter(java.lang.String)
-     */
-    public String getParameter(String name)
+    public PortalContext getPortalContext()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getParameterNames()
-     */
-    public Enumeration getParameterNames()
+    public PortletMode getPortletMode()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getParameterValues(java.lang.String)
-     */
-    public String[] getParameterValues(String name)
+    public PortletPreferences getPreferences()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getParameterMap()
-     */
-    public Map getParameterMap()
+    public Map<String, String[]> getPrivateParameterMap()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#isSecure()
-     */
-    public boolean isSecure()
+    public Enumeration<String> getProperties(String arg0)
     {
         // TODO Auto-generated method stub
-        return false;
+        return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#setAttribute(java.lang.String, java.lang.Object)
-     */
-    public void setAttribute(String name, Object o)
+    public String getProperty(String arg0)
     {
         // TODO Auto-generated method stub
+        return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#removeAttribute(java.lang.String)
-     */
-    public void removeAttribute(String name)
+    public Enumeration<String> getPropertyNames()
     {
         // TODO Auto-generated method stub
+        return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getRequestedSessionId()
-     */
-    public String getRequestedSessionId()
+    public Map<String, String[]> getPublicParameterMap()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#isRequestedSessionIdValid()
-     */
-    public boolean isRequestedSessionIdValid()
+    public String getRemoteUser()
     {
         // TODO Auto-generated method stub
-        return false;
+        return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getResponseContentType()
-     */
-    public String getResponseContentType()
+    public String getRequestedSessionId()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getResponseContentTypes()
-     */
-    public Enumeration getResponseContentTypes()
+    public String getResponseContentType()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getLocale()
-     */
-    public Locale getLocale()
+    public Enumeration<String> getResponseContentTypes()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getScheme()
-     */
     public String getScheme()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getServerName()
-     */
     public String getServerName()
     {
         // TODO Auto-generated method stub
         return null;
     }
-    /* (non-Javadoc)
-     * @see javax.portlet.PortletRequest#getServerPort()
-     */
     public int getServerPort()
     {
         // TODO Auto-generated method stub
         return 0;
     }
-    
-    public Enumeration getLocales()
+    public Principal getUserPrincipal()
     {
+        // TODO Auto-generated method stub
         return null;
     }
-    
+    public String getWindowID()
+    {
+        // TODO Auto-generated method stub
+        return null;
+    }
+    public WindowState getWindowState()
+    {
+        // TODO Auto-generated method stub
+        return null;
+    }
+    public boolean isPortletModeAllowed(PortletMode arg0)
+    {
+        // TODO Auto-generated method stub
+        return false;
+    }
+    public boolean isRequestedSessionIdValid()
+    {
+        // TODO Auto-generated method stub
+        return false;
+    }
+    public boolean isSecure()
+    {
+        // TODO Auto-generated method stub
+        return false;
+    }
+    public boolean isUserInRole(String arg0)
+    {
+        // TODO Auto-generated method stub
+        return false;
+    }
+    public boolean isWindowStateAllowed(WindowState arg0)
+    {
+        // TODO Auto-generated method stub
+        return false;
+    }
+    public void removeAttribute(String arg0)
+    {
+        // TODO Auto-generated method stub
+    }
+    public void setAttribute(String arg0, Object arg1)
+    {
+        // TODO Auto-generated method stub
+    }
 }

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/portlet/MockPortletSession.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/portlet/MockPortletSession.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/portlet/MockPortletSession.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/portlet/MockPortletSession.java Thu Oct 16 16:01:57 2008
@@ -16,8 +16,11 @@
  */
 package org.apache.jetspeed.mockobjects.portlet;
 
+import java.util.Collections;
 import java.util.Enumeration;
 import java.util.Hashtable;
+import java.util.Map;
+
 import javax.portlet.PortletContext;
 import javax.portlet.PortletSession;
 
@@ -31,7 +34,7 @@
 public class MockPortletSession implements PortletSession
 {
     // Hashtable (not HashMap) makes enumerations easier to work with
-    Hashtable attributes = new Hashtable();
+    Hashtable<String, Object> attributes = new Hashtable<String, Object>();
 
     public MockPortletSession()
     {     
@@ -57,7 +60,7 @@
     /* (non-Javadoc)
      * @see javax.portlet.PortletSession#getAttributeNames(int)
      */
-    public Enumeration getAttributeNames(int scope)
+    public Enumeration<String> getAttributeNames(int scope)
     {
         return attributes.keys();
     }
@@ -139,7 +142,7 @@
         attributes.put(name, value);
     }
 
-    public Enumeration getAttributeNames()
+    public Enumeration<String> getAttributeNames()
     {
         return this.getAttributeNames(PortletSession.PORTLET_SCOPE);
     }    
@@ -168,4 +171,17 @@
         // TODO Auto-generated method stub
         return null;
     }
+
+
+    public Map<String, Object> getAttributeMap()
+    {
+        return Collections.unmodifiableMap(attributes);
+    }
+
+
+    public Map<String, Object> getAttributeMap(int scope)
+    {
+        // TODO: need to filter on scope
+        return getAttributeMap();
+    }
 }

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/request/MockRequestContext.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/request/MockRequestContext.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/request/MockRequestContext.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/mockobjects/request/MockRequestContext.java Thu Oct 16 16:01:57 2008
@@ -32,11 +32,10 @@
 import org.apache.jetspeed.container.url.PortalURL;
 import org.apache.jetspeed.mockobjects.MockHttpServletRequest;
 import org.apache.jetspeed.om.page.ContentPage;
+import org.apache.jetspeed.om.portlet.Language;
 import org.apache.jetspeed.pipeline.Pipeline;
 import org.apache.jetspeed.profiler.Profiler;
 import org.apache.jetspeed.request.RequestContext;
-import org.apache.pluto.om.portlet.Language;
-import org.apache.pluto.om.portlet.ObjectID;
 import org.apache.pluto.om.portlet.PortletDefinition;
 import org.apache.jetspeed.container.PortletWindow;
 
@@ -68,9 +67,9 @@
     private Map objects;
     
     /* (non-Javadoc)
-     * @see org.apache.jetspeed.request.RequestContext#getUserInfoMap(org.apache.pluto.om.common.ObjectID)
+     * @see org.apache.jetspeed.request.RequestContext#getUserInfoMap(String)
      */
-    public Map getUserInfoMap( ObjectID oid )
+    public Map getUserInfoMap( String appName )
     {
         // TODO Auto-generated method stub
         return null;

Added: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/Language.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/Language.java?rev=705396&view=auto
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/Language.java (added)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/Language.java Thu Oct 16 16:01:57 2008
@@ -0,0 +1,36 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.jetspeed.om.portlet;
+
+import java.util.List;
+import java.util.Locale;
+import java.util.ResourceBundle;
+
+import org.apache.pluto.om.portlet.PortletInfo;
+
+/**
+ * @version $Id$
+ *
+ */
+public interface Language extends PortletInfo
+{
+    Locale getLocale();
+    void setKeywords(List<String> keywords);
+    public void setLocale(Locale locale);    
+    ResourceBundle getResourceBundle();
+}

Propchange: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/Language.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/Language.java
------------------------------------------------------------------------------
    svn:keywords = Id

Propchange: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/Language.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Copied: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletApplication.java (from r705312, portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/common/portlet/PortletApplication.java)
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletApplication.java?p2=portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletApplication.java&p1=portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/common/portlet/PortletApplication.java&r1=705312&r2=705396&rev=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/common/portlet/PortletApplication.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletApplication.java Thu Oct 16 16:01:57 2008
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.jetspeed.om.common.portlet;
+package org.apache.jetspeed.om.portlet;
 
 import java.util.List;
 

Propchange: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletApplication.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.2

Propchange: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletApplication.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletApplication.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletDefinition.java (from r705312, portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/common/portlet/PortletDefinitionComposite.java)
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletDefinition.java?p2=portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletDefinition.java&p1=portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/common/portlet/PortletDefinitionComposite.java&r1=705312&r2=705396&rev=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/common/portlet/PortletDefinitionComposite.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletDefinition.java Thu Oct 16 16:01:57 2008
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.jetspeed.om.common.portlet;
+package org.apache.jetspeed.om.portlet;
 
 import java.io.Serializable;
 import java.util.Collection;
+import java.util.List;
 import java.util.Locale;
 
 import org.apache.jetspeed.om.common.GenericMetadata;
 import org.apache.jetspeed.om.common.ParameterComposite;
 import org.apache.jetspeed.om.common.preference.PreferenceComposite;
 import org.apache.pluto.om.portlet.DescriptionSet;
-import org.apache.pluto.om.portlet.Language;
-import org.apache.pluto.om.portlet.LanguageSet;
+import org.apache.jetspeed.om.portlet.Language;
 import org.apache.pluto.om.portlet.ParameterSet;
 import org.apache.pluto.om.portlet.Preference;
 import org.apache.pluto.om.portlet.PreferenceSet;
@@ -34,7 +34,6 @@
 import org.apache.pluto.om.portlet.DisplayName;
 import org.apache.pluto.om.portlet.DisplayNameSet;
 import org.apache.pluto.om.portlet.PortletApplicationDefinition;
-import org.apache.pluto.om.portlet.PortletDefinition;
 import org.apache.pluto.om.portlet.SecurityRoleRef;
 import org.apache.pluto.om.portlet.SecurityRoleRefSet;
 
@@ -46,25 +45,21 @@
  * @version $Id$
  *
  */
-public interface PortletDefinitionComposite extends PortletDefinition, Serializable
+public interface PortletDefinition extends org.apache.pluto.om.portlet.PortletDefinition, Serializable
 {
     GenericMetadata getMetadata();
     
     void setMetadata(GenericMetadata metadata);
     
-    void addLanguage(Language lang);
-    
     void addLanguage(String title, String shortTitle, String keywords, Locale locale);
-
-    void addContentType(ContentType cType);
     
-    void addContentType(String contentType, Collection modes);
-
-    void setLanguageSet(LanguageSet languages);
+    Language getLanguage(Locale locale);
+    
+    List<Language> getLanguages();
     
-    String getResourceBundle();
+    void addContentType(ContentType cType);
     
-    Collection getSupportedLocales();
+    void addContentType(String contentType, Collection modes);
 
     /**
      * The PreferenceSet is a collection user-defineable preferences

Propchange: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletDefinition.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.10

Propchange: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletDefinition.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/om/portlet/PortletDefinition.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/request/RequestContext.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/request/RequestContext.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/security/SecurityAccessController.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/security/SecurityAccessController.java Thu Oct 16 16:01:57 2008
@@ -16,7 +16,7 @@
  */
 package org.apache.jetspeed.security;
 
-import org.apache.jetspeed.om.common.portlet.PortletDefinitionComposite;
+import org.apache.jetspeed.om.portlet.PortletDefinition;
 
 /**
  * <p>
@@ -57,7 +57,7 @@
      * @param mask A mask <code>JetspeedActions</code> such as view, edit
      * @return true if access is granted, false if access denied based on policy or constraints
      */
-    boolean checkPortletAccess(PortletDefinitionComposite portlet, int mask);
+    boolean checkPortletAccess(PortletDefinition portlet, int mask);
     
     /**
      * Returns the configured security mode for this accessor

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/userinfo/UserInfoManager.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/userinfo/UserInfoManager.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/userinfo/UserInfoManager.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/userinfo/UserInfoManager.java Thu Oct 16 16:01:57 2008
@@ -20,8 +20,6 @@
 
 import org.apache.jetspeed.request.RequestContext;
 
-import org.apache.pluto.om.portlet.ObjectID;
-
 /**
  * <p>The {@link UserInfoManager} retrieve the Map that will be set as a 
  * <code>(PortletRequest.USER_INFO</code> request attribute for a specific
@@ -58,5 +56,5 @@
      * @param context The request context.
      * @return The {@link PortletRequest.USER_INFO} map.
      */
-    Map<String, String> getUserInfoMap(ObjectID oid, RequestContext context);
+    Map<String, String> getUserInfoMap(String appName, RequestContext context);
 }

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-commons/src/main/java/org/apache/jetspeed/container/JetspeedPortletContext.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-commons/src/main/java/org/apache/jetspeed/container/JetspeedPortletContext.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-commons/src/main/java/org/apache/jetspeed/container/JetspeedPortletContext.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-commons/src/main/java/org/apache/jetspeed/container/JetspeedPortletContext.java Thu Oct 16 16:01:57 2008
@@ -29,7 +29,7 @@
 
 import org.apache.jetspeed.dispatcher.JetspeedRequestDispatcher;
 import org.apache.jetspeed.om.common.JetspeedServiceReference;
-import org.apache.jetspeed.om.common.portlet.PortletApplication;
+import org.apache.jetspeed.om.portlet.PortletApplication;
 import org.apache.jetspeed.services.JetspeedPortletServices;
 import org.apache.jetspeed.services.PortletServices;
 import org.apache.pluto.om.portlet.PortletApplicationDefinition;

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-commons/src/main/java/org/apache/jetspeed/portlet/PortletObjectProxy.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-commons/src/main/java/org/apache/jetspeed/portlet/PortletObjectProxy.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-commons/src/main/java/org/apache/jetspeed/portlet/PortletObjectProxy.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-commons/src/main/java/org/apache/jetspeed/portlet/PortletObjectProxy.java Thu Oct 16 16:01:57 2008
@@ -46,8 +46,8 @@
 import javax.portlet.UnavailableException;
 import org.apache.jetspeed.Jetspeed;
 import org.apache.jetspeed.components.portletregistry.PortletRegistry;
-import org.apache.jetspeed.om.common.portlet.PortletDefinitionComposite;
-import org.apache.jetspeed.om.common.portlet.PortletApplication;
+import org.apache.jetspeed.om.portlet.PortletApplication;
+import org.apache.jetspeed.om.portlet.PortletDefinition;
 import org.apache.jetspeed.om.servlet.WebApplicationDefinition;
 import org.apache.jetspeed.factory.PortletFactory;
 import org.apache.jetspeed.factory.PortletInstance;
@@ -306,7 +306,7 @@
             PortletFactory portletFactory = (PortletFactory) Jetspeed.getComponentManager().getComponent("portletFactory");
             ServletContext portalAppContext = ((ServletConfig) Jetspeed.getComponentManager().getComponent("ServletConfig")).getServletContext();
             
-            PortletDefinitionComposite portletDef = (PortletDefinitionComposite) registry.getPortletDefinitionByUniqueName(this.customConfigModePortletUniqueName);
+            PortletDefinition portletDef = (PortletDefinition) registry.getPortletDefinitionByUniqueName(this.customConfigModePortletUniqueName);
             PortletApplication portletApp = (PortletApplication) portletDef.getApplication();
             WebApplicationDefinition webAppDef = portletApp.getWebApplicationDefinition();
             String portletAppName = webAppDef.getContextRoot();



---------------------------------------------------------------------
To unsubscribe, e-mail: jetspeed-dev-unsubscribe@portals.apache.org
For additional commands, e-mail: jetspeed-dev-help@portals.apache.org
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletregistry/RegistryEventListener.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/components/portletregistry/RegistryEventListener.java Thu Oct 16 16:01:57 2008
@@ -16,8 +16,8 @@
  */
 package org.apache.jetspeed.components.portletregistry;
 
-import org.apache.jetspeed.om.common.portlet.PortletApplication;
-import org.apache.jetspeed.om.common.portlet.PortletDefinitionComposite;
+import org.apache.jetspeed.om.portlet.PortletApplication;
+import org.apache.jetspeed.om.portlet.PortletDefinition;
 
 /**
  * This interface describes the page manager event listener
@@ -42,9 +42,9 @@
      *           updated by the registry or when the
      *           state modification is otherwise detected
      *
      * @param PortletDefinitionComposite new managed portlet definition 
      */
-    void portletUpdated(PortletDefinitionComposite def);
+    void portletUpdated(PortletDefinition def);
 
     /**
      * applicationRemoved - invoked when the definition of a portlet application is
@@ -58,8 +58,8 @@
      * portletUpdated - invoked when the definition of a portlet definition is
      *           removed by the registry 
      *
      * @param PortletDefinitionComposite new managed portlet definition if known
      */
-    void portletRemoved(PortletDefinitionComposite def);
+    void portletRemoved(PortletDefinition def);
     
 }
@@ -42,9 +42,9 @@
      *           state modification is otherwise detected
      *
-     * @param PortletDefinitionComposite new managed portlet definition 
+     * @param PortletDefinition new managed portlet definition 
      */
@@ -58,8 +58,8 @@
      *           removed by the registry 
      *
-     * @param PortletDefinitionComposite new managed portlet definition if known
+     * @param PortletDefinition new managed portlet definition if known
      */

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/factory/PortletFactory.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/factory/PortletFactory.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================
--- portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/request/RequestContext.java (original)
+++ portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/request/RequestContext.java Thu Oct 16 16:01:57 2008
@@ -32,8 +32,7 @@
 import org.apache.jetspeed.om.page.ContentPage;
 import org.apache.jetspeed.pipeline.Pipeline;
 import org.apache.jetspeed.profiler.Profiler;
-import org.apache.pluto.om.portlet.Language;
-import org.apache.pluto.om.portlet.ObjectID;
+import org.apache.jetspeed.om.portlet.Language;
 import org.apache.pluto.om.portlet.PortletDefinition;
 import org.apache.jetspeed.container.PortletWindow;
 
@@ -380,10 +379,10 @@
     
     /**
      * Returns the user info map of user attributes for a given portlet application.</p>
      * @param oid The portlet application object id.
      * @return The PortletRequest.USER_INFO map.
      */
-    Map getUserInfoMap(ObjectID oid);
+    Map getUserInfoMap(String appName);
     
     /**
      * 
@@ -380,10 +379,10 @@
     /**
      * Returns the user info map of user attributes for a given portlet application.</p>
-     * @param oid The portlet application object id.
+     * @param appName The portlet application name.
      * @return The PortletRequest.USER_INFO map.
      */

Modified: portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/security/SecurityAccessController.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/portal/branches/JS2-871-pluto-2.0-upgrade/jetspeed-api/src/main/java/org/apache/jetspeed/security/SecurityAccessController.java?rev=705396&r1=705395&r2=705396&view=diff
==============================================================================